import uuid
import typer
import httpx
import lxml.html
from datetime import datetime
from typing_extensions import Annotated
from .controller import add_task

app = typer.Typer()


@app.command()
def new(
    name: Annotated[str, typer.Option("-n", "--name", help="name")] = "",
    category: Annotated[str, typer.Option("-c", "--category", help="name")] = "",
    due: Annotated[str, typer.Option("-d", "--due", help="due")] = "",
    url: Annotated[str, typer.Option("-u", "--url", help="URL")] = "",
):
    required = ["name", "category"]

    if url and not name:
        resp = httpx.get(url, follow_redirects=True)
        doc = lxml.html.fromstring(resp.text)
        try:
            name = doc.xpath("//title/text()")[0]
            print(f"fetched {url} name... {name}")
        except IndexError:
            name = ""

    if "name" in required and not name:
        name = typer.prompt("Name")
    if "category" in required and not category:
        category = typer.prompt("Category")
    due = typer.prompt("Due (YYYY-MM-DD):")
    # TODO: validate/allow blank

    add_task(name, category, due)
    typer.echo("Created new task!")


@app.command()
def search(q: str):
    pass


if __name__ == "__main__":
    app()
